==> nektar-4.3.0.tar.xz: nektar++-4.3.0/library/NekMeshUtils/SurfaceMeshing/OptimiseFunctions.h <==
////////////////////////////////////////////////////////////////////////////////
//
//  File: Curvemesh.h
//
//  For more information, please see: http://www.nektar.info/
//
//  The MIT License
//
//  Copyright (c) 2006 Division of Applied Mathematics, Brown University (USA),
//  Department of Aeronautics, Imperial College London (UK), and Scientific
//  Computing and Imaging Institute, University of Utah (USA).
//
//  License for the specific language governing rights and limitations under
//  Permission is hereby granted, free of charge, to any person obtaining a
//  copy of this software and associated documentation files (the "Software"),
//  to deal in the Software without restriction, including without limitation
//  the rights to use, copy, modify, merge, publish, distribute, sublicense,
//  and/or sell copies of the Software, and to permit persons to whom the
//  Software is furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included
//  in all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
//  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
//  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//  DEALINGS IN THE SOFTWARE.
//
//  Description: object for individual curve meshes.
//
////////////////////////////////////////////////////////////////////////////////

#ifndef NEKTAR_MESHUTILS_SURFACEMESH_OPTIMISEFUNCTIONS_H
#define NEKTAR_MESHUTILS_SURFACEMESH_OPTIMISEFUNCTIONS_H

#include <LocalRegions/MatrixKey.h>
#include <NekMeshUtils/CADSystem/CADObj.h>
#include <NekMeshUtils/CADSystem/CADSurf.h>
#include <NekMeshUtils/Optimisation/OptimiseObj.h>

namespace Nektar
{
namespace NekMeshUtils
{

class OptiEdge : public OptiObj
{
public:
    friend class MemoryManager<OptiEdge>;

    OptiEdge(Array<OneD, NekDouble> a,
             Array<OneD, NekDouble> dis,
             CADObjSharedPtr ob)
    {
        all = a;
        z   = dis;
        o   = ob;
    };

    ~OptiEdge(){};

    NekDouble F(Array<OneD, NekDouble> xitst);
    DNekMat dF(Array<OneD, NekDouble> xitst);
    Array<OneD, NekDouble> Getxi();
    Array<OneD, NekDouble> Getli();
    Array<OneD, NekDouble> Getui();
    void Update(Array<OneD, NekDouble> xinew);

    Array<OneD, NekDouble> GetSolution()
    {
        return all;
    };

private:
    CADObjSharedPtr o;
    Array<OneD, NekDouble> z;
    Array<OneD, NekDouble> all;
};
typedef boost::shared_ptr<OptiEdge> OptiEdgeSharedPtr;

class OptiFace : public OptiObj
{
public:
    friend class MemoryManager<OptiFace>;

    OptiFace(Array<OneD, Array<OneD, NekDouble> > a,
             map<pair<int, int>, NekDouble> w,
             set<pair<int, int> > sp,
             CADSurfSharedPtr su)
    {
        uv     = a;
        z      = w;
        spring = sp;
        s      = su;
        np     = uv.num_elements();
        nq     = 0.5 * (-1 + sqrt(1 + 8 * np));
        ni     = (nq - 3) * (nq - 2) / 2;
    };

    ~OptiFace(){};

    NekDouble F(Array<OneD, NekDouble> xitst);
    DNekMat dF(Array<OneD, NekDouble> xitst);
    Array<OneD, NekDouble> Getxi();
    Array<OneD, NekDouble> Getli();
    Array<OneD, NekDouble> Getui();
    void Update(Array<OneD, NekDouble> xinew);

    Array<OneD, Array<OneD, NekDouble> > GetSolution()
    {
        return uv;
    };

private:
    CADSurfSharedPtr s;
    map<pair<int, int>, NekDouble> z;
    set<pair<int, int> > spring;
    Array<OneD, Array<OneD, NekDouble> > uv;
    int ni, np, nq;
};
typedef boost::shared_ptr<OptiFace> OptiFaceSharedPtr;
}
}
#endif

==> nektar-4.4.1.tar.xz: nektar++-4.4.1/library/NekMeshUtils/SurfaceMeshing/OptimiseFunctions.h <==
////////////////////////////////////////////////////////////////////////////////
//
//  File: Curvemesh.h
//
//  For more information, please see: http://www.nektar.info/
//
//  The MIT License
//
//  Copyright (c) 2006 Division of Applied Mathematics, Brown University (USA),
//  Department of Aeronautics, Imperial College London (UK), and Scientific
//  Computing and Imaging Institute, University of Utah (USA).
//
//  License for the specific language governing rights and limitations under
//  Permission is hereby granted, free of charge, to any person obtaining a
//  copy of this software and associated documentation files (the "Software"),
//  to deal in the Software without restriction, including without limitation
//  the rights to use, copy, modify, merge, publish, distribute, sublicense,
//  and/or sell copies of the Software, and to permit persons to whom the
//  Software is furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included
//  in all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
//  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
//  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//  DEALINGS IN THE SOFTWARE.
//
//  Description: object for individual curve meshes.
//
////////////////////////////////////////////////////////////////////////////////

#ifndef NEKTAR_MESHUTILS_SURFACEMESH_OPTIMISEFUNCTIONS_H
#define NEKTAR_MESHUTILS_SURFACEMESH_OPTIMISEFUNCTIONS_H

#include <LocalRegions/MatrixKey.h>
#include <NekMeshUtils/CADSystem/CADObject.h>
#include <NekMeshUtils/CADSystem/CADSurf.h>
#include <NekMeshUtils/Optimisation/OptimiseObj.h>

namespace Nektar
{
namespace NekMeshUtils
{

class OptiEdge : public OptiObj
{
public:
    friend class MemoryManager<OptiEdge>;

    OptiEdge(Array<OneD, NekDouble> a,
             Array<OneD, NekDouble> dis,
             CADObjectSharedPtr ob)
    {
        all = a;
        z   = dis;
        o   = ob;
    };

    ~OptiEdge(){};

    NekDouble F(Array<OneD, NekDouble> xitst);
    DNekMat dF(Array<OneD, NekDouble> xitst);
    Array<OneD, NekDouble> Getxi();
    Array<OneD, NekDouble> Getli();
    Array<OneD, NekDouble> Getui();
    void Update(Array<OneD, NekDouble> xinew);

    Array<OneD, NekDouble> GetSolution()
    {
        return all;
    };

private:
    CADObjectSharedPtr o;
    Array<OneD, NekDouble> z;
    Array<OneD, NekDouble> all;
};
typedef boost::shared_ptr<OptiEdge> OptiEdgeSharedPtr;

}
}
#endif
